﻿Imports System.ComponentModel
Imports System.ComponentModel.Design.Serialization
Imports System.Globalization
Imports System.Reflection


''' <summary>
''' Konvertiert <see cref="PointF"/>-Objekte aus einem Typ in einen anderen.
''' </summary>
''' <remarks>Diese Klasse wurde per Disassembler aus <see cref="SizeFConverter"/> abgeleitet. SizeF -> PointF, Width -> X, Height -> Y.</remarks>
''' <seealso cref="SizeFConverter"/>
Public Class PointFConverter
      Inherits TypeConverter

      ''' <summary>
      ''' Initialisiert eine neue Instanz der <see cref="PointFConverter"/>-Klasse.
      ''' </summary>
      Public Sub New()
      End Sub

      ''' <summary>
      ''' Gibt einen Wert zurück, der angibt, ob der Konverter mithilfe des angegebenen Kontexts aus dem angegebenen Typ in den <see cref="PointF"/>-Typ konvertieren kann
      ''' </summary>
      ''' <param name="context">Ein ITypeDescriptorContext, mit dem zusätzlicher Kontext bereitgestellt werden kann. </param>
      ''' <param name="sourceType">Ein Type, der den Ausgangstyp der Konvertierung darstellt.</param>
      ''' <returns><b>true</b>, um anzugeben, dass die Konvertierung ausgeführt werden kann, andernfalls <b>false</b>.</returns>
      ''' <seealso cref="SizeFConverter.CanConvertFrom(ITypeDescriptorContext, Type)"/>
      Public Overrides Function CanConvertFrom(ByVal context As ITypeDescriptorContext, ByVal sourceType As Type) As Boolean
         Return ((sourceType Is GetType(String)) OrElse MyBase.CanConvertFrom(context, sourceType))
      End Function

      ''' <summary>
      ''' Gibt einen Wert zurück, der angibt, ob der <see cref="PointF"/>Converter eine <see cref="PointF"/> in den angegebenen Typ konvertieren kann.
      ''' </summary>
      ''' <param name="context">Ein ITypeDescriptorContext, mit dem zusätzlicher Kontext bereitgestellt werden kann.</param>
      ''' <param name="destinationType">Eine Type-Klasse, die den Ausgangstyp der Konvertierung darstellt.</param>
      ''' <returns><b>true</b>, um anzugeben, dass die Konvertierung ausgeführt werden kann, andernfalls <b>false</b>.</returns>
      ''' <seealso cref="SizeFConverter.CanConvertTo(ITypeDescriptorContext, Type)"/>
      Public Overrides Function CanConvertTo(ByVal context As ITypeDescriptorContext, ByVal destinationType As Type) As Boolean
         Return ((destinationType Is GetType(InstanceDescriptor)) OrElse MyBase.CanConvertTo(context, destinationType))
      End Function

      ''' <summary>
      ''' Konvertiert das angegebene Objekt unter Verwendung des angegebenen Kontexts und der Kulturinformationen in den Typ dieses Konverters.
      ''' </summary>
      ''' <param name="context">Eine ITypeDescriptorContext-Schnittstelle, die einen Formatierungskontext bereitstellt.</param>
      ''' <param name="culture">Die als aktuelle Kultur zu verwendenden CultureInfo. </param>
      ''' <param name="value">Die zu konvertierende Object-Klasse.</param>
      ''' <returns>Ein Object, das den konvertierten Wert darstellt. </returns>
      ''' <seealso cref="SizeFConverter.ConvertFrom(ITypeDescriptorContext, CultureInfo, Object)"/>
      Public Overrides Function ConvertFrom(ByVal context As ITypeDescriptorContext, ByVal culture As CultureInfo, ByVal value As Object) As Object
         Dim str As String = TryCast(value, String)
         If (str Is Nothing) Then
            Return MyBase.ConvertFrom(context, culture, value)
         End If
         Dim str2 As String = str.Trim
         If (str2.Length = 0) Then
            Return Nothing
         End If
         If (culture Is Nothing) Then
            culture = CultureInfo.CurrentCulture
         End If
         Dim ch As Char = culture.TextInfo.ListSeparator.Chars(0)
         Dim separator As Char() = New Char() {ch}
         Dim strArray As String() = str2.Split(separator)
         Dim numArray As Single() = New Single(strArray.Length - 1) {}
         Dim converter As TypeConverter = TypeDescriptor.GetConverter(GetType(Single))
         Dim i As Integer
         For i = 0 To numArray.Length - 1
            numArray(i) = CSng(converter.ConvertFromString(context, culture, strArray(i)))
         Next i
         If (numArray.Length = 2) Then
            Return New PointF(numArray(0), numArray(1))
         End If
         Throw New ArgumentException("TextParseFailedFormat")
      End Function

      ''' <summary>
      ''' Konvertiert das angegebene Wertobjekt unter Verwendung des angegebenen Kontexts und der angegebenen Kulturinformationen in den angegebenen Typ.
      ''' </summary>
      ''' <param name="context">Eine ITypeDescriptorContext-Schnittstelle, die einen Formatierungskontext bereitstellt.</param>
      ''' <param name="culture">CultureInfo Wenn <b>Nothing</b> übergeben wird, wird von der aktuellen Kultur ausgegangen.</param>
      ''' <param name="value">Die zu konvertierende Object-Klasse.</param>
      ''' <param name="destinationType">Der Type, in den der value-Parameter konvertiert werden soll.</param>
      ''' <returns>Ein Object, das den konvertierten Wert darstellt.</returns>
      ''' <seealso cref="SizeFConverter.ConvertTo(ITypeDescriptorContext, CultureInfo, Object, Type)"/>
      Public Overrides Function ConvertTo(ByVal context As ITypeDescriptorContext, ByVal culture As CultureInfo, ByVal value As Object, ByVal destinationType As Type) As Object
         If (destinationType Is Nothing) Then
            Throw New ArgumentNullException("destinationType")
         End If
         If ((destinationType Is GetType(String)) AndAlso TypeOf value Is PointF) Then
            Dim ef As PointF = DirectCast(value, PointF)
            If (culture Is Nothing) Then
               culture = CultureInfo.CurrentCulture
            End If
            Dim converter As TypeConverter = TypeDescriptor.GetConverter(GetType(Single))
            Dim strArray As String() = New String(2 - 1) {}
            Dim num As Integer = 0
            strArray(num) = converter.ConvertToString(context, culture, ef.X)
            num += 1
            strArray(num) = converter.ConvertToString(context, culture, ef.Y)
            num += 1
            Return String.Join((culture.TextInfo.ListSeparator & " "), strArray)
         End If
         If ((destinationType Is GetType(InstanceDescriptor)) AndAlso TypeOf value Is PointF) Then
            Dim ef2 As PointF = DirectCast(value, PointF)
            Dim types As Type() = New Type() {GetType(Single), GetType(Single)}
            Dim constructor As ConstructorInfo = GetType(PointF).GetConstructor(types)
            If (Not constructor Is Nothing) Then
               Return New InstanceDescriptor(constructor, New Object() {ef2.X, ef2.Y})
            End If
         End If
         Return MyBase.ConvertTo(context, culture, value, destinationType)
      End Function

      ''' <summary>
      ''' Erstellt eine Instanz von <see cref="PointF"/> mit den angegebenen Eigenschaftswerten unter Verwendung des angegebenen Kontexts.
      ''' </summary>
      ''' <param name="context">Ein ITypeDescriptorContext, mit dem zusätzlicher Kontext bereitgestellt werden kann. </param>
      ''' <param name="propertyValues">Ein IDictionary mit Eigenschaftennamen und -werten.</param>
      ''' <returns>Ein Object, das die neue <see cref="PointF"/> darstellt, oder Nothing, wenn das Objekt nicht erstellt werden kann.</returns>
      ''' <seealso cref="SizeFConverter.CreateInstance(ITypeDescriptorContext, IDictionary)"/>
      Public Overrides Function CreateInstance(ByVal context As ITypeDescriptorContext, ByVal propertyValues As IDictionary) As Object
         Return New PointF(CSng(propertyValues.Item("X")), CSng(propertyValues.Item("Y")))
      End Function

      ''' <summary>
      ''' Gibt einen Wert zurück, der angibt, ob beim Ändern eines Werts für dieses Objekt ein Aufruf der CreateInstance-Methode zum Erstellen eines neuen Werts erforderlich ist.
      ''' </summary>
      ''' <param name="context">Eine ITypeDescriptorContext-Schnittstelle, die einen Formatierungskontext bereitstellt. Dieser Wert kann <b>Nothing</b> sein.</param>
      ''' <returns>Gibt immer <b>true</b> zurück.</returns>
      ''' <seealso cref="SizeFConverter.GetCreateInstanceSupported(ITypeDescriptorContext)"/>
      Public Overrides Function GetCreateInstanceSupported(ByVal context As ITypeDescriptorContext) As Boolean
         Return True
      End Function

      ''' <summary>
      ''' Ruft Eigenschaften für den <see cref="PointF"/>-Typ mit dem angegebenen Kontext und den angegebenen Attributen ab.
      ''' </summary>
      ''' <param name="context">Ein ITypeDescriptorContext, mit dem zusätzlicher Kontext bereitgestellt werden kann.</param>
      ''' <param name="value">Das Object, für das Eigenschaften zurückgegeben werden sollen.</param>
      ''' <param name="attributes">Ein Array von Attribute-Objekten, die die Eigenschaften beschreiben. </param>
      ''' <returns>Eine PropertyDescriptorCollection, die die Eigenschaften enthält.</returns>
      ''' <seealso cref="SizeFConverter.GetProperties(ITypeDescriptorContext, Object, Attribute())"/>
      Public Overrides Function GetProperties(ByVal context As ITypeDescriptorContext, ByVal value As Object, ByVal attributes As Attribute()) As PropertyDescriptorCollection
         Dim names As String() = New String() {"X", "Y"}
         Return TypeDescriptor.GetProperties(GetType(PointF), attributes).Sort(names)
      End Function

      ''' <summary>
      ''' Gibt zurück, ob der <see cref="PointF"/>-Typ Eigenschaften unterstützt.
      ''' </summary>
      ''' <param name="context">Ein ITypeDescriptorContext, mit dem zusätzlicher Kontext bereitgestellt werden kann.</param>
      ''' <returns>Gibt immer <b>true</b> zurück.</returns>
      ''' <seealso cref="SizeFConverter.GetPropertiesSupported(ITypeDescriptorContext)"/>
      Public Overrides Function GetPropertiesSupported(ByVal context As ITypeDescriptorContext) As Boolean
         Return True
      End Function

   End Class
